@@ -867,6 +867,8 @@ class OrgAlkTitration():
         # file
         class UnreliableRMSValue(UserWarning):
             pass
+        class IncreasingRMSFracChangeLim(UserWarning):
+            pass
 
         self.minimise(minimiser_no)
         RMS_init = self.ssr(minimiser_no)
@@ -986,7 +988,7 @@ class OrgAlkTitration():
         output_filename = os.path.join(master_results_path,master_results_filename)
         master_results_exists = os.path.exists(output_filename)
 
-        template_results_filename = "/Users/ct6g18/Python/org-alk-sausage-machine/template_spreadsheets/master_results_template.xlsx"
+        template_results_filename = os.path.join(ROOT_DIR,"src/template_spreadsheets/master_results_template.xlsx")
 
         if not master_results_exists:
             print("Master Results Spreadsheet does not exist, copying from template")
